//+------------------------------------------------------------------+
//|                                                       SRM-TL.mq4 |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+


#property indicator_separate_window
#property indicator_minimum 0
#property indicator_maximum 1
#property indicator_buffers 3
#property indicator_color1 Crimson
#property indicator_color2 MediumBlue
#property indicator_color3 Gold
//---- input parameters

extern int       TimeFrame        = 240;
extern string    note_TimeFrames_ = "M1;5,15,30,60H1;240H4;1440D1;10080W1;43200MN|0-currentTF";
extern bool      alertsOn         = true;
extern bool      alertsOnCurrent  = true;
extern bool      alertsMessage    = true;
extern bool      alertsSound      = true;
extern bool      alertsEmail      = false;


//---- buffers
double ExtMapBuffer1[];
double ExtMapBuffer2[];
double ExtMapBuffer3[];
string TimeFrameStr;
string IndicatorFileName;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
  string short_name;
  SetIndexStyle(0,DRAW_HISTOGRAM,STYLE_SOLID,5,Crimson);
  SetIndexBuffer(0,ExtMapBuffer1);
  SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_SOLID,5, MediumBlue);
  SetIndexBuffer(1,ExtMapBuffer2);
  SetIndexStyle(2,DRAW_HISTOGRAM,STYLE_SOLID,5, Gold);
  SetIndexBuffer(2,ExtMapBuffer3);

  switch(TimeFrame)
   {
   case 1: string TimeFrameStr = "M1" ;  break;
   case 5     :   TimeFrameStr = "M5" ;  break;
   case 15    :   TimeFrameStr = "M15";  break;
   case 30    :   TimeFrameStr = "M30";  break;
   case 60    :   TimeFrameStr = "H1" ;  break;
   case 240   :   TimeFrameStr = "H4" ;  break;
   case 1440  :   TimeFrameStr = "D1" ;  break;
   case 10080 :   TimeFrameStr = "W1" ;  break;
   case 43200 :   TimeFrameStr = "MN1";  break;
   default :      TimeFrameStr = "TF0";
   }

   TimeFrame         = MathMax(TimeFrame,Period());
   IndicatorFileName = WindowExpertName();
   short_name=("HA_AO_TL_mtf("+TimeFrameStr+")") ;
   IndicatorShortName(short_name);
   return(0);
}
int deinit()
{
   return(0);
}

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   
   int    counted_bars=IndicatorCounted();
   int limit,i;
   
   if(counted_bars<0) return(-1);
   if(counted_bars>0) counted_bars--;
           limit=Bars-counted_bars;
           
           if (TimeFrame != Period()) limit = MathMax(limit,TimeFrame/Period());
           

      for(i=limit; i>=0; i--)
      {
      int y = iBarShift(NULL,TimeFrame,Time[i]);

      double tlbuy  = iCustom(NULL,TimeFrame,"TrendLord-1",50,1,y);
      double tlsell = iCustom(NULL,TimeFrame,"TrendLord-1",50,2,y); 

      double haOpen  = iCustom(NULL,TimeFrame,"Heiken Ashi",2,y);
      double haClose = iCustom(NULL,TimeFrame,"Heiken Ashi",3,y); 

      double aobuy  = iAO(Symbol(),TimeFrame,y);
      double aosell = iAO(Symbol(),TimeFrame,y);
      
      
      if(haOpen < haClose && tlbuy >= 0 && aobuy >= 0 && tlsell == EMPTY_VALUE) ExtMapBuffer2[i] = 1;
      if(haOpen > haClose && tlbuy == EMPTY_VALUE && aosell < 0 && tlsell > 0)  ExtMapBuffer1[i] = 1;
      if (ExtMapBuffer2[i] == EMPTY_VALUE && ExtMapBuffer1[i] == EMPTY_VALUE)   ExtMapBuffer3[i] = 1;
    
      if (alertsOn)
      {
      if (alertsOnCurrent)
      int whichBar = 0;
      else   whichBar = 1;
      if (ExtMapBuffer2[whichBar] > 0 && ExtMapBuffer1[whichBar] < 0 && ExtMapBuffer3[whichBar] == EMPTY_VALUE) doAlert(" trend changeed to UP");
      if (ExtMapBuffer1[whichBar] > 0 && ExtMapBuffer2[whichBar] < 0 && ExtMapBuffer3[whichBar] == EMPTY_VALUE) doAlert(" trend changeed ro DOWN");
    }
  }   
  return(0);
}

//+------------------------------------------------------------------+
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," ArrZZx2 ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," ArrZZx2"),message);
             if (alertsSound)   PlaySound("alert2.wav");
      }
}



